@@ -7,7 +7,7 @@ function(y, x, lag=1, ... )
         stop("Time series properties of y and x are different.\n")}
 
     name.y <- deparse(substitute(y)); name.x <- deparse(substitute(x))
-    z <- ts(residuals(lm(y~x)), start=start(y), end=end(y), freq=tsp(y)[3])  
+    z <- ts(residuals(lm(y~x)), start=start(y), end=end(y), frequency=tsp(y)[3])  
     lz <- lag(z, k=-1) 
 
     dx <- diff(x); dy <- diff(y)
@@ -15,7 +15,7 @@ function(y, x, lag=1, ... )
         var.name=c(name.x, name.y), suffix=".t_", include.orig=TRUE)       
     if (tsp(xx)[1] > tsp(lz)[1]) { aa <- start(xx) } else {aa <- start(lz)} 
     if (tsp(xx)[2] < tsp(lz)[2]) { bb <- end(xx)   } else {bb <- end(lz)}   
-    data <- window(cbind(xx, lz), start=aa, end=bb, freq=tsp(y)[3])
+    data <- window(cbind(xx, lz), start=aa, end=bb, frequency=tsp(y)[3])
     colnames(data) <- c(colnames(xx), "ECT.t_1")
 
     DepVar.x  <- data[, 1]
